
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at

// http://www.apache.org/licenses/LICENSE-2.0

// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This file was initially generated by gen_to_start.go (add link), as a start
// of the Traffic Ops golang data model

package api

import (
	"encoding/json"
	_ "github.com/apache/trafficcontrol/traffic_ops/experimental/server/output_format" // needed for swagger
	"github.com/jmoiron/sqlx"
	"log"
	"time"
)

type Divisions struct {
	Name      string         `db:"name" json:"name"`
	CreatedAt time.Time      `db:"created_at" json:"createdAt"`
	Links     DivisionsLinks `json:"_links" db:-`
}

type DivisionsLinks struct {
	Self string `db:"self" json:"_self"`
}

// @Title getDivisionsById
// @Description retrieves the divisions information for a certain id
// @Accept  application/json
// @Param   id              path    int     false        "The row id"
// @Success 200 {array}    Divisions
// @Resource /api/2.0
// @Router /api/2.0/divisions/{id} [get]
func getDivision(name string, db *sqlx.DB) (interface{}, error) {
	ret := []Divisions{}
	arg := Divisions{}
	arg.Name = name
	queryStr := "select *, concat('" + API_PATH + "divisions/', name) as self"
	queryStr += " from divisions WHERE name=:name"
	nstmt, err := db.PrepareNamed(queryStr)
	err = nstmt.Select(&ret, arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	nstmt.Close()
	return ret, nil
}

// @Title getDivisionss
// @Description retrieves the divisions
// @Accept  application/json
// @Success 200 {array}    Divisions
// @Resource /api/2.0
// @Router /api/2.0/divisions [get]
func getDivisions(db *sqlx.DB) (interface{}, error) {
	ret := []Divisions{}
	queryStr := "select *, concat('" + API_PATH + "divisions/', name) as self"
	queryStr += " from divisions"
	err := db.Select(&ret, queryStr)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return ret, nil
}

// @Title postDivisions
// @Description enter a new divisions
// @Accept  application/json
// @Param                 Body body     Divisions   true "Divisions object that should be added to the table"
// @Success 200 {object}    output_format.ApiWrapper
// @Resource /api/2.0
// @Router /api/2.0/divisions [post]
func postDivision(payload []byte, db *sqlx.DB) (interface{}, error) {
	var v Divisions
	err := json.Unmarshal(payload, &v)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	sqlString := "INSERT INTO divisions("
	sqlString += "name"
	sqlString += ",created_at"
	sqlString += ") VALUES ("
	sqlString += ":name"
	sqlString += ",:created_at"
	sqlString += ")"
	result, err := db.NamedExec(sqlString, v)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}

// @Title putDivisions
// @Description modify an existing divisionsentry
// @Accept  application/json
// @Param   id              path    int     true        "The row id"
// @Param                 Body body     Divisions   true "Divisions object that should be added to the table"
// @Success 200 {object}    output_format.ApiWrapper
// @Resource /api/2.0
// @Router /api/2.0/divisions/{id}  [put]
func putDivision(name string, payload []byte, db *sqlx.DB) (interface{}, error) {
	var arg Divisions
	err := json.Unmarshal(payload, &arg)
	arg.Name = name
	if err != nil {
		log.Println(err)
		return nil, err
	}
	sqlString := "UPDATE divisions SET "
	sqlString += "name = :name"
	sqlString += ",created_at = :created_at"
	sqlString += " WHERE name=:name"
	result, err := db.NamedExec(sqlString, arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}

// @Title delDivisionsById
// @Description deletes divisions information for a certain id
// @Accept  application/json
// @Param   id              path    int     false        "The row id"
// @Success 200 {array}    Divisions
// @Resource /api/2.0
// @Router /api/2.0/divisions/{id} [delete]
func delDivision(name string, db *sqlx.DB) (interface{}, error) {
	arg := Divisions{}
	arg.Name = name
	result, err := db.NamedExec("DELETE FROM divisions WHERE name=:name", arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}
