
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at

// http://www.apache.org/licenses/LICENSE-2.0

// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This file was initially generated by gen_to_start.go (add link), as a start
// of the Traffic Ops golang data model

package api

import (
	"encoding/json"
	_ "github.com/apache/trafficcontrol/traffic_ops/experimental/server/output_format" // needed for swagger
	"github.com/jmoiron/sqlx"
	null "gopkg.in/guregu/null.v3"
	"log"
)

type Roles struct {
	Name        string      `db:"name" json:"name"`
	Description null.String `db:"description" json:"description"`
	PrivLevel   int64       `db:"priv_level" json:"privLevel"`
	Links       RolesLinks  `json:"_links" db:-`
}

type RolesLinks struct {
	Self string `db:"self" json:"_self"`
}

type RolesLink struct {
	ID  string `db:"role" json:"name"`
	Ref string `db:"roles_name_ref" json:"_ref"`
}

// @Title getRolesById
// @Description retrieves the roles information for a certain id
// @Accept  application/json
// @Param   id              path    int     false        "The row id"
// @Success 200 {array}    Roles
// @Resource /api/2.0
// @Router /api/2.0/roles/{id} [get]
func getRole(name string, db *sqlx.DB) (interface{}, error) {
	ret := []Roles{}
	arg := Roles{}
	arg.Name = name
	queryStr := "select *, concat('" + API_PATH + "roles/', name) as self"
	queryStr += " from roles WHERE name=:name"
	nstmt, err := db.PrepareNamed(queryStr)
	err = nstmt.Select(&ret, arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	nstmt.Close()
	return ret, nil
}

// @Title getRoless
// @Description retrieves the roles
// @Accept  application/json
// @Success 200 {array}    Roles
// @Resource /api/2.0
// @Router /api/2.0/roles [get]
func getRoles(db *sqlx.DB) (interface{}, error) {
	ret := []Roles{}
	queryStr := "select *, concat('" + API_PATH + "roles/', name) as self"
	queryStr += " from roles"
	err := db.Select(&ret, queryStr)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return ret, nil
}

// @Title postRoles
// @Description enter a new roles
// @Accept  application/json
// @Param                 Body body     Roles   true "Roles object that should be added to the table"
// @Success 200 {object}    output_format.ApiWrapper
// @Resource /api/2.0
// @Router /api/2.0/roles [post]
func postRole(payload []byte, db *sqlx.DB) (interface{}, error) {
	var v Roles
	err := json.Unmarshal(payload, &v)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	sqlString := "INSERT INTO roles("
	sqlString += "name"
	sqlString += ",description"
	sqlString += ",priv_level"
	sqlString += ") VALUES ("
	sqlString += ":name"
	sqlString += ",:description"
	sqlString += ",:priv_level"
	sqlString += ")"
	result, err := db.NamedExec(sqlString, v)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}

// @Title putRoles
// @Description modify an existing rolesentry
// @Accept  application/json
// @Param   id              path    int     true        "The row id"
// @Param                 Body body     Roles   true "Roles object that should be added to the table"
// @Success 200 {object}    output_format.ApiWrapper
// @Resource /api/2.0
// @Router /api/2.0/roles/{id}  [put]
func putRole(name string, payload []byte, db *sqlx.DB) (interface{}, error) {
	var arg Roles
	err := json.Unmarshal(payload, &arg)
	arg.Name = name
	if err != nil {
		log.Println(err)
		return nil, err
	}
	sqlString := "UPDATE roles SET "
	sqlString += "name = :name"
	sqlString += ",description = :description"
	sqlString += ",priv_level = :priv_level"
	sqlString += " WHERE name=:name"
	result, err := db.NamedExec(sqlString, arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}

// @Title delRolesById
// @Description deletes roles information for a certain id
// @Accept  application/json
// @Param   id              path    int     false        "The row id"
// @Success 200 {array}    Roles
// @Resource /api/2.0
// @Router /api/2.0/roles/{id} [delete]
func delRole(name string, db *sqlx.DB) (interface{}, error) {
	arg := Roles{}
	arg.Name = name
	result, err := db.NamedExec("DELETE FROM roles WHERE name=:name", arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}
