
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at

// http://www.apache.org/licenses/LICENSE-2.0

// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This file was initially generated by gen_to_start.go (add link), as a start
// of the Traffic Ops golang data model

package api

import (
	"encoding/json"
	_ "github.com/apache/trafficcontrol/traffic_ops/experimental/server/output_format" // needed for swagger
	"github.com/jmoiron/sqlx"
	"log"
	"time"
)

type ServersTypes struct {
	Name        string            `db:"name" json:"name"`
	Description string            `db:"description" json:"description"`
	CreatedAt   time.Time         `db:"created_at" json:"createdAt"`
	Links       ServersTypesLinks `json:"_links" db:-`
}

type ServersTypesLinks struct {
	Self string `db:"self" json:"_self"`
}

type ServersTypesLink struct {
	ID  string `db:"type" json:"type"`
	Ref string `db:"servers_types_name_ref" json:"_ref"`
}

// @Title getServersTypesById
// @Description retrieves the servers_types information for a certain id
// @Accept  application/json
// @Param   id              path    int     false        "The row id"
// @Success 200 {array}    ServersTypes
// @Resource /api/2.0
// @Router /api/2.0/servers_types/{id} [get]
func getServersType(name string, db *sqlx.DB) (interface{}, error) {
	ret := []ServersTypes{}
	arg := ServersTypes{}
	arg.Name = name
	queryStr := "select *, concat('" + API_PATH + "servers_types/', name) as self"
	queryStr += " from servers_types WHERE name=:name"
	nstmt, err := db.PrepareNamed(queryStr)
	err = nstmt.Select(&ret, arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	nstmt.Close()
	return ret, nil
}

// @Title getServersTypess
// @Description retrieves the servers_types
// @Accept  application/json
// @Success 200 {array}    ServersTypes
// @Resource /api/2.0
// @Router /api/2.0/servers_types [get]
func getServersTypes(db *sqlx.DB) (interface{}, error) {
	ret := []ServersTypes{}
	queryStr := "select *, concat('" + API_PATH + "servers_types/', name) as self"
	queryStr += " from servers_types"
	err := db.Select(&ret, queryStr)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return ret, nil
}

// @Title postServersTypes
// @Description enter a new servers_types
// @Accept  application/json
// @Param                 Body body     ServersTypes   true "ServersTypes object that should be added to the table"
// @Success 200 {object}    output_format.ApiWrapper
// @Resource /api/2.0
// @Router /api/2.0/servers_types [post]
func postServersType(payload []byte, db *sqlx.DB) (interface{}, error) {
	var v ServersTypes
	err := json.Unmarshal(payload, &v)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	sqlString := "INSERT INTO servers_types("
	sqlString += "name"
	sqlString += ",description"
	sqlString += ",created_at"
	sqlString += ") VALUES ("
	sqlString += ":name"
	sqlString += ",:description"
	sqlString += ",:created_at"
	sqlString += ")"
	result, err := db.NamedExec(sqlString, v)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}

// @Title putServersTypes
// @Description modify an existing servers_typesentry
// @Accept  application/json
// @Param   id              path    int     true        "The row id"
// @Param                 Body body     ServersTypes   true "ServersTypes object that should be added to the table"
// @Success 200 {object}    output_format.ApiWrapper
// @Resource /api/2.0
// @Router /api/2.0/servers_types/{id}  [put]
func putServersType(name string, payload []byte, db *sqlx.DB) (interface{}, error) {
	var arg ServersTypes
	err := json.Unmarshal(payload, &arg)
	arg.Name = name
	if err != nil {
		log.Println(err)
		return nil, err
	}
	sqlString := "UPDATE servers_types SET "
	sqlString += "name = :name"
	sqlString += ",description = :description"
	sqlString += ",created_at = :created_at"
	sqlString += " WHERE name=:name"
	result, err := db.NamedExec(sqlString, arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}

// @Title delServersTypesById
// @Description deletes servers_types information for a certain id
// @Accept  application/json
// @Param   id              path    int     false        "The row id"
// @Success 200 {array}    ServersTypes
// @Resource /api/2.0
// @Router /api/2.0/servers_types/{id} [delete]
func delServersType(name string, db *sqlx.DB) (interface{}, error) {
	arg := ServersTypes{}
	arg.Name = name
	result, err := db.NamedExec("DELETE FROM servers_types WHERE name=:name", arg)
	if err != nil {
		log.Println(err)
		return nil, err
	}
	return result, err
}
